@@ -1,6 +1,6 @@
 package SQLite::Work;
 {
-  $SQLite::Work::VERSION = '0.13';
+  $SQLite::Work::VERSION = '0.14';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ SQLite::Work - report on and update an SQLite database.
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -1200,7 +1200,7 @@ sub get_total_matching {
     my $table = $args{table};
 
     # build up the query data
-    my @where = $self->build_where_conditions(
+    my @where = $self->build_where_conditions(%args,
 	where=>$args{where}, not_where=>$args{not_where});
     
     my $total_query = "SELECT COUNT(*) FROM $table";
@@ -1582,7 +1582,7 @@ sub make_selections {
     $offset = 0 if $offset < 0;
 
     # build up the query data
-    my @where = $self->build_where_conditions(
+    my @where = $self->build_where_conditions(%args,
 	where=>$args{where}, not_where=>$args{not_where});
     
     my $jquery = '';
@@ -1822,7 +1822,7 @@ sub get_distinct_col {
     my $colname = $args{colname};
 
     # build up the query data
-    my @where = $self->build_where_conditions(
+    my @where = $self->build_where_conditions(%args,
 	where=>$args{where}, not_where=>$args{not_where});
     
     my $query = "SELECT DISTINCT $colname FROM $table";
@@ -2212,18 +2212,24 @@ sub format_report {
 
     # make headers for all the headers
     # set the headers and entry columns
-    my %in_header = ();
     my %prev_head = ();
     if (@sort_by and @headers)
     {
-	for (my $i=0; $i < @headers && $i < @sort_by; $i++)
+        for (my $i=0; $i < @headers && $i < @sort_by; $i++)
 	{
 	    $prev_head{$i} = '';
 	    # read each header template if it's a file
 	    $headers[$i] = $self->get_template($headers[$i]);
-	}
-	# find out what fields are in the headers
-	my $all_headers = join('', @headers);
+            # read each 'group' template if the template is a file
+            if (@groups and exists $groups[$i] and defined $groups[$i])
+            {
+		$groups[$i] = $self->get_template($groups[$i]);
+            }
+        }
+
+	# find out what fields are in the headers and groups
+        my %in_header = ();
+	my $all_headers = join('', @headers, @groups);
 	while ($all_headers =~ m/{\$(\w+)[:\w]*}/)
 	{
 	    $in_header{$1} = 1;
@@ -2241,14 +2247,6 @@ sub format_report {
 		$show_cols{$col} = 0;
 	    }
 	}
-	# read each 'group' template if the template is a file
-	if (@groups)
-	{
-	    foreach my $group (@groups)
-	    {
-		$group = $self->get_template($group);
-	    }
-	}
     }
     #
     # Set the nicer column name labels
