@@ -1,6 +1,6 @@
 package SQLite::Work::CGI;
 {
-  $SQLite::Work::CGI::VERSION = '0.13';
+  $SQLite::Work::CGI::VERSION = '0.14';
 }
 use strict;
 use warnings;
@@ -11,7 +11,7 @@ SQLite::Work::CGI - Report and update a SQLite database using CGI
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -1045,9 +1045,9 @@ EOT
 	    my (@vals) = $self->{cgi}->param($pfield);
 	    foreach my $val (@vals)
 	    {
-		$result .= "<input type='hidden' name='$pfield' value='";
-		$result .= $val;
-		$result .= "'/>\n";
+                $result .=<<EOT;
+<input type='hidden' name="$pfield" value="${val}"/>
+EOT
 	    }
 	}
     }
